Module format

Module format 

Format detection, capabilities, and serialization for value-model formats.

Each format in this module is loaded into a common serde_json::Value. Conversion rules are expressed as format capabilities so adding another value-model format only requires registering its aliases, extensions, conversion family, and serializer/parser here.

Enums

ConversionOperation
Which operation is checking a conversion edge.
Format
Supported textual formats for the value-model disassembler.
FormatFamily
A family of formats that can safely convert among themselves.