pub struct Meta {
pub source_format: SerdeFormat,
pub file_format: SerdeFormat,
pub source_filename: Option<String>,
pub root: Root,
}Expand description
Description of how a disassembled directory was produced.
Fields
source_format: SerdeFormatFormat the original input file was read from.
file_format: SerdeFormatFormat used to write the split files on disk.
source_filename: Option<String>Original input file name (with extension), used as a default when reassembling without an explicit output path.
root: RootWhether the document root was an object or an array.
Implementations