pub struct ReassembleOptions {
pub input_dir: PathBuf,
pub output: Option<PathBuf>,
pub output_format: Option<Format>,
pub post_purge: bool,
}Expand description
Options controlling reassembly.
Fields
input_dir: PathBufDirectory containing the disassembled files and metadata.
output: Option<PathBuf>Path to write the reassembled file to. If None, written next to
the input directory using the original source filename (or the
directory name with the chosen format’s extension).
output_format: Option<Format>Format to write the reassembled file in. Defaults to the format recorded as the original source format in the metadata.
post_purge: boolRemove the input directory after a successful reassembly.