pub struct DisassembleOptions {
pub input: PathBuf,
pub input_format: Option<Format>,
pub output_dir: Option<PathBuf>,
pub output_format: Option<Format>,
pub unique_id: Option<String>,
pub pre_purge: bool,
pub post_purge: bool,
}Expand description
Options controlling disassembly.
Fields
input: PathBufPath to the input config file.
input_format: Option<Format>Format to read the input as. If None, inferred from the extension.
output_dir: Option<PathBuf>Directory to write split files into. If None, defaults to a
directory next to the input file named after the input’s file stem.
output_format: Option<Format>Format to write split files in. Defaults to input_format.
unique_id: Option<String>For array roots, name array-element files using the value of this field if present on each element (must be a scalar).
pre_purge: boolIf true, remove the contents of the output directory before writing.
post_purge: boolIf true, delete the input file after disassembling.