Module format

Module format 

Format detection and serialization for JSON, JSON5, and YAML.

All three formats are loaded into a common serde_json::Value so that a file in one format can be re-emitted in any of the others.

Enums

Format
Supported textual formats for the JSON-family disassembler.