pub enum Format {
Json,
Json5,
Yaml,
}Expand description
Supported textual formats for the JSON-family disassembler.
Variants
Implementations
Sourceimpl Format
impl Format
Sourcepub fn from_path(path: &Path) -> Result<Self>
pub fn from_path(path: &Path) -> Result<Self>
Best-effort detection of a format from a file path’s extension.
Sourcepub fn parse(self, input: &str) -> Result<Value>
pub fn parse(self, input: &str) -> Result<Value>
Parse a string in this format into a generic Value.