Metadata sidecar describing a disassembled directory.
A .config-disassembler.json file is written into the disassembly output
directory so reassembly can reconstruct the original key order, root type,
and the format the split files were written in.
Structs
- Meta
- Description of how a disassembled directory was produced.
Enums
- Root
- Description of the document root.
Constants
- META_
FILENAME - File name of the metadata sidecar.
Type Aliases
- Serde
Format - Serde-friendly metadata format type.